==> foundry_platform_sdk-0.47.0.tar.gz: foundry_platform_sdk-0.47.0/foundry/v2/connectivity/models/_table_import_dict.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry.v2.connectivity.models._connection_rid import ConnectionRid
from foundry.v2.connectivity.models._table_import_config_dict import TableImportConfigDict  # NOQA
from foundry.v2.connectivity.models._table_import_display_name import TableImportDisplayName  # NOQA
from foundry.v2.connectivity.models._table_import_mode import TableImportMode
from foundry.v2.connectivity.models._table_import_rid import TableImportRid
from foundry.v2.datasets.models._branch_name import BranchName
from foundry.v2.datasets.models._dataset_rid import DatasetRid


class TableImportDict(TypedDict):
    """TableImport"""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    rid: TableImportRid

    connectionRid: ConnectionRid
    """The RID of the Connection (formerly known as a source) that the Table Import uses to import data."""

    datasetRid: DatasetRid
    """The RID of the output dataset."""

    branchName: NotRequired[BranchName]
    """The branch name in the output dataset that will contain the imported data. Defaults to `master` for most enrollments."""

    displayName: TableImportDisplayName

    importMode: TableImportMode

    config: TableImportConfigDict

==> foundry_platform_sdk-0.91.0.tar.gz: foundry_platform_sdk-0.91.0/foundry/v2/connectivity/models/_table_import_dict.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry.v2.connectivity.models._connection_rid import ConnectionRid
from foundry.v2.connectivity.models._table_import_allow_schema_changes import (
    TableImportAllowSchemaChanges,
)  # NOQA
from foundry.v2.connectivity.models._table_import_config_dict import TableImportConfigDict  # NOQA
from foundry.v2.connectivity.models._table_import_display_name import TableImportDisplayName  # NOQA
from foundry.v2.connectivity.models._table_import_mode import TableImportMode
from foundry.v2.connectivity.models._table_import_rid import TableImportRid
from foundry.v2.datasets.models._branch_name import BranchName
from foundry.v2.datasets.models._dataset_rid import DatasetRid


class TableImportDict(TypedDict):
    """TableImport"""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    rid: TableImportRid

    connectionRid: ConnectionRid
    """The RID of the Connection (also known as a source) that the Table Import uses to import data."""

    datasetRid: DatasetRid
    """The RID of the output dataset."""

    branchName: NotRequired[BranchName]
    """The branch name in the output dataset that will contain the imported data. Defaults to `master` for most enrollments."""

    displayName: TableImportDisplayName

    importMode: TableImportMode

    allowSchemaChanges: TableImportAllowSchemaChanges
    """Allow the TableImport to succeed if the schema of imported rows does not match the existing dataset's schema. Defaults to false for new table imports."""

    config: TableImportConfigDict
